TypeKind

Enum TypeKind 

pub enum TypeKind<'ast> {
    Elementary(ElementaryType),
    Array(Box<'ast, TypeArray<'ast>>),
    Function(Box<'ast, TypeFunction<'ast>>),
    Mapping(Box<'ast, TypeMapping<'ast>>),
    Custom(AstPath<'ast>),
}
The kind of a type.

Variants



Elementary(ElementaryType)

An elementary/primitive type.



Array(Box<'ast, TypeArray<'ast>>)

$element[$($size)?]



Function(Box<'ast, TypeFunction<'ast>>)

function($($parameters),*) $($attributes)* $(returns ($($returns),+))?



Mapping(Box<'ast, TypeMapping<'ast>>)

mapping($key $($key_name)? => $value $($value_name)?)



Custom(AstPath<'ast>)

A custom type.

Implementations

Source

impl TypeKind<'_>

pub fn is_elementary(&self) -> bool

Returns true if the type is an elementary type.

Note that this does not include Custom types.

pub fn is_custom(&self) -> bool

Returns true if the type is a custom type.