CallArgs

Struct CallArgs 

pub struct CallArgs<'ast> {
    pub span: Span,
    pub kind: CallArgsKind<'ast>,
}
A list of function call arguments.

Fields

span: Span

The span of the arguments. This points to the parenthesized list of arguments.

If the list is empty, this points to the empty ()/({}) or to where the ( would be.

kind: CallArgsKind<'ast>

Implementations

Source

impl<'ast> CallArgs<'ast>

pub fn empty(span: Span) -> Self

Creates a new empty list of arguments.

span should be an empty span.

pub fn is_dummy(&self) -> bool

Returns true if the argument list is not present in the source code.

For example, a modifier m can be invoked in a function declaration as m or m(). In the first case, this returns true, and the span will point to after m. In the second case, this returns false.

pub fn len(&self) -> usize

Returns the length of the arguments.

pub fn is_empty(&self) -> bool

Returns true if the list of arguments is empty.

pub fn exprs( &self, ) -> impl ExactSizeIterator<Item = &Expr<'ast>> + DoubleEndedIterator + Clone

Returns an iterator over the expressions.

pub fn exprs_mut( &mut self, ) -> impl ExactSizeIterator<Item = &mut Box<'ast, Expr<'ast>>> + DoubleEndedIterator

Returns an iterator over the expressions.