Lit

Struct Lit 

pub struct Lit<'ast> {
    pub span: Span,
    pub symbol: Symbol,
    pub kind: LitKind<'ast>,
}
A literal: hex"1234", 5.6 ether.

Note that multiple string literals of the same kind are concatenated together to form a single Lit (see LitKind::Str), thus the span will be the span of the entire literal, and the symbol will be the concatenated string.

Reference: https://docs.soliditylang.org/en/latest/grammar.html#a4.SolidityParser.literal

Fields

span: Span

The concatenated span of the literal.

symbol: Symbol

The original contents of the literal as written in the source code, excluding any quotes.

If this is a concatenated string literal, this will contain only the first string literal’s contents. For all the other string literals, see the extra field in LitKind::Str.

kind: LitKind<'ast>

The “semantic” representation of the literal lowered from the original tokens. Strings are unescaped and concatenated, hexadecimal forms are eliminated, etc.

Implementations

Source

impl Lit<'_>

pub fn first_span(&self) -> Span

Returns the span of the first string literal in this literal.

pub fn literals(&self) -> impl Iterator<Item = (Span, Symbol)> + '_

Returns an iterator over all the literals that were concatenated to form this literal.

pub fn copy_without_data<'a>(&self) -> Lit<'a>

Returns a copy of this literal with any allocated data discarded.