pub struct SourceUnit<'ast> {
pub items: Box<'ast, IndexSlice<ItemId, [Item<'ast>]>>,
}Expand description
A Solidity source file.
Fields
items: Box<'ast, IndexSlice<ItemId, [Item<'ast>]>>The source unit’s items.
Implementations
Sourceimpl<'ast> SourceUnit<'ast>
impl<'ast> SourceUnit<'ast>
Sourcepub fn new(items: BoxSlice<'ast, Item<'ast>>) -> Self
pub fn new(items: BoxSlice<'ast, Item<'ast>>) -> Self
Creates a new source unit from the given items.
Sourcepub fn count_contracts(&self) -> usize
pub fn count_contracts(&self) -> usize
Counts the number of contracts in the source unit.
Sourcepub fn imports(&self) -> impl Iterator<Item = (Span, &ImportDirective<'ast>)>
pub fn imports(&self) -> impl Iterator<Item = (Span, &ImportDirective<'ast>)>
Returns an iterator over the source unit’s imports.