TypeSize

Struct TypeSize 

pub struct TypeSize(/* private fields */);
Byte size of a fixed-bytes, integer, or fixed-point number (M) type. Valid values: 0..=32.

Implementations

Source

impl TypeSize

pub const ZERO: Self

The value zero. Note that this is not a valid size for a fixed-bytes type.

pub const MAX: u8 = 32u8

The maximum byte value of a TypeSize.

pub const fn new(bytes: u8) -> Option<Self>

Creates a new TypeSize from a u8 number of bytes.

pub fn new_int_bits(bits: u16) -> Self

Creates a new TypeSize from a u8 number of bits.

Panics if bits is not a multiple of 8 or greater than 256.

pub fn try_new_int_bits(bits: u16) -> Option<Self>

Creates a new TypeSize for an integer type.

Returns None if bits is not a multiple of 8 or greater than 256.

pub fn new_fb_bytes(bytes: u8) -> Self

Creates a new TypeSize for a fixed-bytes type.

Panics if bytes is not in the range 1..=32.

pub fn try_new_fb_bytes(bytes: u8) -> Option<Self>

Creates a new TypeSize for a fixed-bytes type.

Returns None if bytes is not in the range 1..=32.

pub const fn bytes(self) -> u8

Returns the number of bytes, with 0 defaulting to MAX.

pub const fn bytes_raw(self) -> u8

Returns the number of bytes.

pub const fn bits(self) -> u16

Returns the number of bits, with 0 defaulting to MAX*8.

pub const fn bits_raw(self) -> u16

Returns the number of bits.

pub const fn int_keyword(self) -> Symbol

Returns the int symbol for the type name.

pub const fn uint_keyword(self) -> Symbol

Returns the uint symbol for the type name.

pub const fn bytes_keyword(self) -> Symbol

Returns the bytesN symbol for the type name.

Panics

Panics if self is 0.