pub struct CallArgs<'ast> {
pub span: Span,
pub kind: CallArgsKind<'ast>,
}Expand description
A list of function call arguments.
Fields
span: SpanThe span of the arguments. This points to the parenthesized list of arguments.
If the list is empty, this points to the empty ()/({}) or to where the ( would be.
kind: CallArgsKind<'ast>Implementations
Sourceimpl<'ast> CallArgs<'ast>
impl<'ast> CallArgs<'ast>
Sourcepub fn empty(span: Span) -> Self
pub fn empty(span: Span) -> Self
Creates a new empty list of arguments.
span should be an empty span.
Sourcepub fn is_dummy(&self) -> bool
pub fn is_dummy(&self) -> bool
Returns true if the argument list is not present in the source code.
For example, a modifier m can be invoked in a function declaration as m or m(). In the
first case, this returns true, and the span will point to after m. In the second case,
this returns false.
Sourcepub fn exprs(
&self,
) -> impl ExactSizeIterator<Item = &Expr<'ast>> + DoubleEndedIterator + Clone
pub fn exprs( &self, ) -> impl ExactSizeIterator<Item = &Expr<'ast>> + DoubleEndedIterator + Clone
Returns an iterator over the expressions.
Sourcepub fn exprs_mut(
&mut self,
) -> impl ExactSizeIterator<Item = &mut Box<'ast, Expr<'ast>>> + DoubleEndedIterator
pub fn exprs_mut( &mut self, ) -> impl ExactSizeIterator<Item = &mut Box<'ast, Expr<'ast>>> + DoubleEndedIterator
Returns an iterator over the expressions.