pub struct Lit<'ast> {
pub span: Span,
pub symbol: Symbol,
pub kind: LitKind<'ast>,
}Expand description
A literal: hex"1234", 5.6 ether.
Note that multiple string literals of the same kind are concatenated together to form a single
Lit (see LitKind::Str), thus the span will be the span of the entire literal, and
the symbol will be the concatenated string.
Reference: https://docs.soliditylang.org/en/latest/grammar.html#a4.SolidityParser.literal
Fields
span: SpanThe concatenated span of the literal.
symbol: SymbolThe original contents of the literal as written in the source code, excluding any quotes.
If this is a concatenated string literal, this will contain only the first string
literal’s contents. For all the other string literals, see the extra field in
LitKind::Str.
kind: LitKind<'ast>The “semantic” representation of the literal lowered from the original tokens. Strings are unescaped and concatenated, hexadecimal forms are eliminated, etc.
Implementations
Sourceimpl Lit<'_>
impl Lit<'_>
Sourcepub fn first_span(&self) -> Span
pub fn first_span(&self) -> Span
Returns the span of the first string literal in this literal.
Sourcepub fn literals(&self) -> impl Iterator<Item = (Span, Symbol)> + '_
pub fn literals(&self) -> impl Iterator<Item = (Span, Symbol)> + '_
Returns an iterator over all the literals that were concatenated to form this literal.
Sourcepub fn copy_without_data<'a>(&self) -> Lit<'a>
pub fn copy_without_data<'a>(&self) -> Lit<'a>
Returns a copy of this literal with any allocated data discarded.