pub struct TryCatchClause<'ast> {
pub span: Span,
pub name: Option<Ident>,
pub args: ParameterList<'ast>,
pub block: Block<'ast>,
}Expand description
Clause of a try/catch block: returns/catch (...) { ... }.
Includes both the successful case and the unsuccessful cases. Names are only allowed for unsuccessful cases.
Reference: https://docs.soliditylang.org/en/latest/grammar.html#a4.SolidityParser.catchClause
Fields
span: SpanThe span of the entire clause, from the returns and catch
keywords, to the closing brace of the block.
name: Option<Ident>The catch clause name: Error, Panic, or custom.
args: ParameterList<'ast>The parameter list for the clause.
block: Block<'ast>A block of statements