pub struct TypeSize(/* private fields */);Expand description
Byte size of a fixed-bytes, integer, or fixed-point number (M) type. Valid values: 0..=32.
Implementations
Sourceimpl TypeSize
impl TypeSize
Sourcepub const ZERO: Self
pub const ZERO: Self
The value zero. Note that this is not a valid size for a fixed-bytes type.
Sourcepub fn new_int_bits(bits: u16) -> Self
pub fn new_int_bits(bits: u16) -> Self
Creates a new TypeSize from a u8 number of bits.
Panics if bits is not a multiple of 8 or greater than 256.
Sourcepub fn try_new_int_bits(bits: u16) -> Option<Self>
pub fn try_new_int_bits(bits: u16) -> Option<Self>
Creates a new TypeSize for an integer type.
Returns None if bits is not a multiple of 8 or greater than 256.
Sourcepub fn new_fb_bytes(bytes: u8) -> Self
pub fn new_fb_bytes(bytes: u8) -> Self
Creates a new TypeSize for a fixed-bytes type.
Panics if bytes is not in the range 1..=32.
Sourcepub fn try_new_fb_bytes(bytes: u8) -> Option<Self>
pub fn try_new_fb_bytes(bytes: u8) -> Option<Self>
Creates a new TypeSize for a fixed-bytes type.
Returns None if bytes is not in the range 1..=32.
Sourcepub const fn int_keyword(self) -> Symbol
pub const fn int_keyword(self) -> Symbol
Returns the int symbol for the type name.
Sourcepub const fn uint_keyword(self) -> Symbol
pub const fn uint_keyword(self) -> Symbol
Returns the uint symbol for the type name.
Sourcepub const fn bytes_keyword(self) -> Symbol
pub const fn bytes_keyword(self) -> Symbol